@@ -1,12 +1,12 @@
 package Data::Sah::CoerceJS;
 
-our $DATE = '2017-03-14'; # DATE
-our $VERSION = '0.021'; # VERSION
+our $DATE = '2017-07-10'; # DATE
+our $VERSION = '0.022'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
-use Log::Any::IfLOG '$log';
+use Log::ger;
 
 use Data::Sah::CoerceCommon;
 use IPC::System::Options;
@@ -84,7 +84,7 @@ sub gen_coercer {
     }
 
     if ($Log_Coercer_Code) {
-        $log->tracef("Coercer code (gen args: %s): %s", \%args, $code);
+        log_trace("Coercer code (gen args: %s): %s", \%args, $code);
     }
 
     return $code if $args{source};
@@ -130,7 +130,7 @@ Data::Sah::CoerceJS - Generate coercer code
 
 =head1 VERSION
 
-This document describes version 0.021 of Data::Sah::CoerceJS (from Perl distribution Data-Sah-Coerce), released on 2017-03-14.
+This document describes version 0.022 of Data::Sah::CoerceJS (from Perl distribution Data-Sah-Coerce), released on 2017-07-10.
 
 =head1 SYNOPSIS
 
